pub struct ScrollViewState { /* private fields */ }Implementations
Sourceimpl ScrollViewState
impl ScrollViewState
Sourcepub fn with_offset(offset: Position) -> Self
pub fn with_offset(offset: Position) -> Self
Create a new scroll view state with the given offset
Sourcepub const fn set_offset(&mut self, offset: Position)
pub const fn set_offset(&mut self, offset: Position)
Set the offset of the scroll view state
Sourcepub const fn scroll_down(&mut self)
pub const fn scroll_down(&mut self)
Move the scroll view state down by one row
Sourcepub fn scroll_page_down(&mut self)
pub fn scroll_page_down(&mut self)
Move the scroll view state down by one page
Sourcepub fn scroll_page_up(&mut self)
pub fn scroll_page_up(&mut self)
Move the scroll view state up by one page
Sourcepub const fn scroll_left(&mut self)
pub const fn scroll_left(&mut self)
Move the scroll view state left by one column
Sourcepub const fn scroll_right(&mut self)
pub const fn scroll_right(&mut self)
Move the scroll view state right by one column
Sourcepub const fn scroll_to_top(&mut self)
pub const fn scroll_to_top(&mut self)
Move the scroll view state to the top of the buffer
Sourcepub fn scroll_to_bottom(&mut self)
pub fn scroll_to_bottom(&mut self)
Move the scroll view state to the bottom of the buffer
If the buffer size is not yet computed (done during the first rendering), it will not
be taken into account and the scroll offset will be set to the maximum value: u16::MAX
Sourcepub fn is_at_bottom(&self) -> bool
pub fn is_at_bottom(&self) -> bool
True if the scroll view state is at the bottom of the buffer
This takes the page size into account. It returns true if the last row in the buffer is visible in the current page.
The buffer and the page size are unknown until computed during the first rendering. If the buffer size is not yet known, this function always returns true. If the page size is not yet known, the current row is treated as a one-row page.
Saturating arithmetic prevents large offsets from overflowing when they are combined with the page size.